@@ -17,7 +17,7 @@ MongoDBx::Tiny::Document - document class
   COLLECTION_NAME 'foo';
 
   # FIELD NAME, sub{}, sub{}..
-  ESSENTIAL qw/code/; # like CDBI's Essential.
+  ESSENTIAL q/code/; # like CDBI's Essential.
   FIELD 'code', INT, LENGTH(10), DEFAULT('0'), REQUIRED;
   FIELD 'name', STR, LENGTH(30), DEFAULT('noname');
 
@@ -606,7 +606,7 @@ sub data {
 
 sub list {
     my $self = shift;
-    keys $self->{_data};
+    keys %{$self->{_data}};
 }
 
 sub get {
